#[repr(u8)]pub enum Side {
King = 0,
Queen = 1,
}Expand description
A side of the board to castle toward.
Variants
Implementations
Sourceimpl Side
Side Finite Set API.
impl Side
Side Finite Set API.
pub const LEN: usize
pub const ALL: [Self; 2]
pub const fn name(self) -> &'static str
pub const fn eq(self, other: Self) -> bool
pub const fn index(self) -> usize
pub const fn from_index(index: u8) -> Option<Self>
pub fn iter() -> impl Iterator<Item = Self>
pub fn iter_rev() -> impl Iterator<Item = Self>
Sourceimpl Side
impl Side
pub const fn chess_rook(self) -> File
pub const fn of_rook(king: Square, rook: File) -> Self
Sourcepub const fn king_to_file(self) -> File
pub const fn king_to_file(self) -> File
The file the king moves to when castling on this side
Sourcepub const fn rook_to_file(self) -> File
pub const fn rook_to_file(self) -> File
The file the rook moves to when castling on this side.