macro_rules! finite_for {
($value:ident in $set:ty $body:block) => { ... };
}Expand description
Loops over all values of a generated finite set in const contexts.
This is a small const-friendly replacement for for value in Type::ALL.
macro_rules! finite_for {
($value:ident in $set:ty $body:block) => { ... };
}Loops over all values of a generated finite set in const contexts.
This is a small const-friendly replacement for for value in Type::ALL.